summaryrefslogtreecommitdiff
path: root/nuttx/configs/cloudctrl/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/cloudctrl/src/up_buttons.c')
-rw-r--r--nuttx/configs/cloudctrl/src/up_buttons.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/nuttx/configs/cloudctrl/src/up_buttons.c b/nuttx/configs/cloudctrl/src/up_buttons.c
index dbad07388..06aa88445 100644
--- a/nuttx/configs/cloudctrl/src/up_buttons.c
+++ b/nuttx/configs/cloudctrl/src/up_buttons.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * configs/cloudctrl/src/up_buttons.c
+ * configs/cloudctrl/src/board_buttons.c
*
* Copyright (C) 2012, 2014 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -78,7 +78,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
*
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, up_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
@@ -99,10 +99,10 @@ void board_button_initialize(void)
}
/****************************************************************************
- * Name: up_buttons
+ * Name: board_buttons
****************************************************************************/
-uint8_t up_buttons(void)
+uint8_t board_buttons(void)
{
uint8_t ret = 0;
int i;
@@ -137,12 +137,12 @@ uint8_t up_buttons(void)
*
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, up_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, up_buttons() may be
* called to collect the state of all buttons. up_buttons() returns an
* 8-bit bit set with each bit associated with a button. See the
* BUTTON_*_BIT and JOYSTICK_*_BIT definitions in board.h for the meaning
* of each bit.
@@ -78,7 +78,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources.
- * After that, up_buttons() may be called to collect the current state of
+ * After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
@@ -137,12 +137,12 @@ uint8_t up_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources.
- * After that, up_buttons() may be called to collect the current state of
+ * After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
@@ -137,12 +137,12 @@ uint8_t up_buttons(void)
* handlers.
*
- * After board_button_initialize() has been called, up_buttons() may be
- * called to collect the state of all buttons. up_buttons() returns an
+ * After board_button_initialize() has been called, board_buttons() may be
+ * called to collect the state of all buttons. board_buttons() returns an
* 8-bit bit set with each bit associated with a button. See the
* BUTTON_*_BIT and JOYSTICK_*_BIT definitions in board.h for the meaning